0.9.9 API documentation: GLM_EXT_quaternion_geometric

| 0.9.9 API documentation

- Main Page
- Modules
- Files

Functions
GLM_EXT_quaternion_geometric
Stable extensions

Provides geometric functions for quaternion types. More...

## Functions
template<typename T , qualifier Q>
GLM_FUNC_QUALIFIER qua< T, Q > | cross (qua< T, Q > const &q1, qua< T, Q > const &q2)
| Compute a cross product. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL T | dot (qua< T, Q > const &x, qua< T, Q > const &y)
| Returns dot product of q1 and q2, i.e., q1[0] * q2[0] + q1[1] * q2[1] + ... More...
template<typename T , qualifier Q>
GLM_FUNC_DECL T | length (qua< T, Q > const &q)
| Returns the norm of a quaternions. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL qua< T, Q > | normalize (qua< T, Q > const &q)
| Returns the normalized quaternion. More...

## Detailed Description

Provides geometric functions for quaternion types.

Include <glm/ext/quaternion_geometric.hpp> to use the features of this extension.

See also
  core_geometric
  GLM_EXT_quaternion_float
  GLM_EXT_quaternion_double

## Function Documentation

GLM_FUNC_QUALIFIER qua<T, Q> glm::cross | ( | qua< T, Q > const & | q1,
|  | qua< T, Q > const & | q2
| ) |  |

Compute a cross product.

Template Parameters

  T | Floating-point scalar types
  Q | Value from qualifier enum

See also
  GLM_EXT_quaternion_geometric

GLM_FUNC_DECL T glm::dot | ( | qua< T, Q > const & | x,
|  | qua< T, Q > const & | y
| ) |  |

Returns dot product of q1 and q2, i.e., q1[0] * q2[0] + q1[1] * q2[1] + ...

Template Parameters

  T | Floating-point scalar types.
  Q | Value from qualifier enum

See also
  GLM_EXT_quaternion_geometric

GLM_FUNC_DECL T glm::length | ( | qua< T, Q > const & | q | ) |

Returns the norm of a quaternions.

Template Parameters

  T | Floating-point scalar types
  Q | Value from qualifier enum

See also
  GLM_EXT_quaternion_geometric

GLM_FUNC_DECL qua<T, Q> glm::normalize | ( | qua< T, Q > const & | q | ) |

Returns the normalized quaternion.

Template Parameters

  T | Floating-point scalar types
  Q | Value from qualifier enum

See also
  GLM_EXT_quaternion_geometric